@@ -2,6 +2,13 @@
 pub enum TextureFormat {
 	Float,
 	Uint8,
+	Uint8Srgb,
+}
+
+impl Default for TextureFormat {
+	fn default() -> Self {
+		TextureFormat::Uint8
+	}
 }
 
 // @TODO: Support 3D texture
